# CreateSessionAndTokenRequest

A request to create a session and a token associated with the session
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**create_token_request** | [**CreateTokenRequest**](CreateTokenRequest.md) |  | 
**session** | [**Session**](Session.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


